import { useState } from "react"
import Taro from "@tarojs/taro"
import { Input, View, Image } from "@tarojs/components"
import withLayout from '@/layouts'
import CustomNav from "@/components/CustomNav"
import MyButton from "@/components/MyButton"
import banner1 from '@/assets/banner/1.jpg'
import resetImg from '@/assets/user/cancel.png'
import './style.less'

export default withLayout((props) => {
  const [name, setName] = useState()
  const [phone, setPhone] = useState()
  const [avatar, setAvatar] = useState(banner1)
  const changeName = (e) => {
    setName(e.detail.value)
  }
  const changePhone = (e) => {
    setPhone(e.detail.value)
  }
  const rulePhone=(val)=>{
    if (!/^1[0-9]{10}$/.test(val)) {
      Taro.showToast({
        title: '请输入正确的11位手机号',
        icon: 'none',
        duration: 2000
      })
      return false
    } else return true
  }
  const handleSave = () => {
    if (rulePhone(phone)) {
      Taro.showToast({
        title: '保存成功',
        icon: 'none',
      })
      Taro.navigateBack({delta:1})
    }
  }
  const resetName=()=>{
    setName()
  }
  const resetPhone=()=>{
    setPhone()
  }
  const changeAvatar=()=>{
    Taro.chooseImage({
      count: 1,
      success: function (res) {
        setAvatar(res.tempFilePaths[0])
        // uploadFile(res.tempFilePaths[0]).then((res2) => {
        //   const date = {
        //     targetId: roomId,
        //     targetType: 'room',
        //     content: res2,
        //     contentType: 'image'
        //   }
        //   saveExtend(date)
        //   setReset(!reset)
        // })
      }
    })
  }
  return (
    <View className='page-index'>
      <View className='index-navbar'>
        <CustomNav title='个人信息' />
      </View>
      <View className='index-container userCard'>
        <View className='avatar' onClick={changeAvatar}>
          <Image src={avatar} className='avatarImg' />
          <View className='change'>更换头像</View>
        </View>
        <View className='userCell'>
          <View>姓名：</View>
          <View style={{ display: 'flex', alignItems: 'center', height: '54px' }}>
            <Input type='text' placeholder='请输入您的姓名' value={name} onBlur={changeName} className='userName' />
            <View className='reset' onClick={resetName}>
              <Image src={resetImg} className='close' />
            </View>
          </View>
        </View>
        <View className='userCell'>
          <View>手机号：</View>
          <View style={{ display: 'flex', alignItems: 'center', height: '54px' }}>
            <Input type='text' placeholder='请输入您的手机号' value={phone} onBlur={changePhone} className='userName' />
            <View className='reset' onClick={resetPhone}>
              <Image src={resetImg} className='close' />
            </View>
          </View>
        </View>
        <View className='bottomBtn'>
          <MyButton value='保存' onClick={handleSave} />
        </View>
      </View>
    </View>
  )
})
